@@ -328,7 +328,7 @@ linc_connection_initiate (LINCConnection        *cnx,
 	int                     fd;
 	gboolean                retval = FALSE;
 	struct sockaddr        *saddr;
-	socklen_t		saddr_len;
+	LincSockLen		saddr_len;
 
 	proto = linc_protocol_find (proto_name);
 
@@ -369,7 +369,7 @@ linc_connection_initiate (LINCConnection        *cnx,
 		options);
 
  out:
-	if (!cnx && fd >= 0) {
+	if (!retval && fd >= 0) {
 		d_printf ("initiation failed\n");
 		close (fd);
 	}
@@ -605,7 +605,7 @@ write_data (LINCConnection *cnx, QueuedWrite *qw)
  * @cnx: the connection to write to
  * @vecs: a structure of iovecs to write - this is altered.
  * @nvecs: the number of populated iovecs
- * @total_size: the total size of the data
+ * @opt_write_opts: optional write options, or NULL
  * 
  * This routine writes data to the abstract connection.
  * FIXME: it allows re-enterancy via linc_connection_iterate
@@ -622,7 +622,7 @@ linc_connection_writev (LINCConnection       *cnx,
 			const LINCWriteOpts  *opt_write_opts)
 {
 	QueuedWrite qw;
-	glong       status;
+	int         status;
 
 	/* FIXME: need an option to turn this off ? */
 	if (cnx->options & LINC_CONNECTION_NONBLOCKING) {
@@ -670,6 +670,7 @@ linc_connection_writev (LINCConnection       *cnx,
  * @cnx: the connection to write to
  * @buf: a pointer to the start of an array of bytes
  * @len: the length of the array in bytes
+ * @opt_write_opts: optional write options, or NULL
  * 
  * Writes a contiguous block of data to the abstract connection.
  * 
@@ -826,7 +827,7 @@ linc_connection_io_handler (GIOChannel  *gioc,
 	LINCConnection      *cnx = data;
 	LINCConnectionClass *klass;
 	int rv, n;
-	socklen_t n_size = sizeof(n);
+	LincSockLen n_size = sizeof (n);
 
 	g_object_ref (G_OBJECT (cnx));
 
