@@ -10,76 +10,14 @@
  *                 Sun Microsystems, Inc.
  */
 #include <config.h>
-#include <dirent.h>
 #include "linc-compat.h"
+#include <dirent.h>
 #include <linc/linc-protocol.h>
 #include <linc/linc-connection.h>
 
 #include "linc-private.h"
 #include "linc-debug.h"
 
-extern LINCProtocolInfo static_linc_protocols[];
-
-/*
- * linc_protocol_all:
- *
- * Returns a list of protocols supported by linc.
- *
- * Note: the list is terminated by a #LINCProtocolInfo with a
- *       NULL name pointer.
- *
- * Return Value: an array of #LINCProtocolInfo structures.
- */
-LINCProtocolInfo * const
-linc_protocol_all (void)
-{
-	return static_linc_protocols;
-}
-
-/*
- * linc_protocol_find:
- * @name: name of the protocol.
- *
- * Find a protocol identified by @name.
- *
- * Return Value: a pointer to a valid #LINCProtocolInfo structure if 
- *               the protocol is supported by linc, NULL otherwise.
- */
-LINCProtocolInfo * const
-linc_protocol_find (const char *name)
-{
-	int i;
-
-	for (i = 0; static_linc_protocols [i].name; i++) {
-		if (!strcmp (name, static_linc_protocols [i].name))
-			return &static_linc_protocols [i];
-	}
-
-	return NULL;
-}
-
-/*
- * linc_protocol_find_num:
- * @family: the family identifier of the protocol - i.e. AF_*
- *
- * Find a protocol identified by @family.
- *
- * Return Value: a pointer to a valid #LINCProtocolInfo structure if
- *               the protocol is supported by linc, NULL otherwise.
- */
-LINCProtocolInfo * const
-linc_protocol_find_num (const int family)
-{
-	int i;
-
-	for (i = 0; static_linc_protocols [i].name; i++) {
-		if (family == static_linc_protocols [i].family)
-			return &static_linc_protocols [i];
-	}
-
-	return NULL;
-}
-
 static char linc_tmpdir [PATH_MAX] = "";
 
 /*
@@ -110,8 +48,8 @@ make_local_tmpdir (const char *dirname)
 			if (statbuf.st_uid != getuid ())
 				g_error ("Owner of %s is not the current user\n", dirname);
 
-			if((statbuf.st_mode & (S_IRWXG|S_IRWXO))
-			   || !S_ISDIR (statbuf.st_mode))
+			if ((statbuf.st_mode & (S_IRWXG|S_IRWXO)) ||
+			    !S_ISDIR (statbuf.st_mode))
 				g_error ("Wrong permissions for %s\n", dirname);
 
 			break;
@@ -154,7 +92,7 @@ linc_set_tmpdir (const char *dir)
 #define LINC_SET_SOCKADDR_LEN(saddr, len)
 #endif
 
-#ifdef AF_INET6
+#if defined(AF_INET6) && defined(RES_USE_INET6)
 #define LINC_RESOLV_SET_IPV6     _res.options |= RES_USE_INET6
 #define LINC_RESOLV_CLEAR_IPV6   _res.options &= ~RES_USE_INET6
 #else
@@ -619,6 +557,13 @@ linc_protocol_get_sockinfo_ipv4 (const LINCProtocolInfo  *proto,
  * Return Value: #TRUE if the function succeeds, #FALSE otherwise.
  */
 #ifdef AF_INET6
+
+/* FIXME: is IN6ADDR_ANY_INIT exported on Mac OS X ? */
+/* on Mac OS X 10.1 inaddr6_any isn't exported by libc */
+#ifndef in6addr_any
+	static const struct in6_addr in6addr_any = { { { 0 } } };
+#endif
+
 static gboolean
 linc_protocol_get_sockinfo_ipv6 (const LINCProtocolInfo  *proto,
 				 const struct sockaddr   *saddr,
@@ -1108,3 +1053,62 @@ linc_protocol_destroy_addr (const LINCProtocolInfo *proto,
 
 }
 
+/*
+ * linc_protocol_all:
+ *
+ * Returns a list of protocols supported by linc.
+ *
+ * Note: the list is terminated by a #LINCProtocolInfo with a
+ *       NULL name pointer.
+ *
+ * Return Value: an array of #LINCProtocolInfo structures.
+ */
+LINCProtocolInfo * const
+linc_protocol_all (void)
+{
+	return static_linc_protocols;
+}
+
+/*
+ * linc_protocol_find:
+ * @name: name of the protocol.
+ *
+ * Find a protocol identified by @name.
+ *
+ * Return Value: a pointer to a valid #LINCProtocolInfo structure if 
+ *               the protocol is supported by linc, NULL otherwise.
+ */
+LINCProtocolInfo * const
+linc_protocol_find (const char *name)
+{
+	int i;
+
+	for (i = 0; static_linc_protocols [i].name; i++) {
+		if (!strcmp (name, static_linc_protocols [i].name))
+			return &static_linc_protocols [i];
+	}
+
+	return NULL;
+}
+
+/*
+ * linc_protocol_find_num:
+ * @family: the family identifier of the protocol - i.e. AF_*
+ *
+ * Find a protocol identified by @family.
+ *
+ * Return Value: a pointer to a valid #LINCProtocolInfo structure if
+ *               the protocol is supported by linc, NULL otherwise.
+ */
+LINCProtocolInfo * const
+linc_protocol_find_num (const int family)
+{
+	int i;
+
+	for (i = 0; static_linc_protocols [i].name; i++) {
+		if (family == static_linc_protocols [i].family)
+			return &static_linc_protocols [i];
+	}
+
+	return NULL;
+}
